@@ -45,15 +45,18 @@ module Control.Monad.Exception.Asynchronous.Lazy (
 
 import qualified Control.Monad.Exception.Synchronous as Sync
 
-import Control.Monad (mplus, liftM, join, )
+import Control.Monad (Monad, return, liftM, mplus, join, (>>=), (>>), )
 import Control.Applicative (Applicative, liftA, )
+import Data.Functor (Functor, fmap, )
 {-
 import Data.Traversable (Traversable, )
 import Data.Foldable (Foldable, )
 -}
 import Data.Monoid(Monoid, mappend, mempty, )
+import Data.Function (const, (.), ($), )
+import Data.Maybe (Maybe(Just, Nothing), maybe, )
 
-import Prelude hiding (zipWith, sequence, mapM, )
+import Prelude (Show, )
 
 
 -- * Plain monad
