@@ -64,16 +64,23 @@ module Control.Monad.Exception.Synchronous (
    ) where
 
 import Control.Applicative (Applicative(pure, (<*>)))
-import Control.Monad (liftM, liftM2, {- MonadPlus(mzero, mplus), -})
+import Control.Monad (Monad, return, fail, liftM, liftM2, (>>=), (>>), (=<<),
+          {- MonadPlus(mzero, mplus), -})
 import Control.Monad.Fix (MonadFix, mfix, )
 import Control.Monad.Trans.Class (MonadTrans, lift, )
 import Control.Monad.Trans.Error (ErrorT(ErrorT, runErrorT))
 import Control.Monad.Trans.Maybe (MaybeT(MaybeT, runMaybeT))
+import Data.Functor (Functor, fmap, )
 import Data.Monoid(Monoid, mappend, mempty, Endo(Endo, appEndo), )
+import Data.Function (flip, const, (.), ($), )
+import Data.Either (Either(Left, Right), either, )
+import Data.Maybe (Maybe(Just, Nothing), maybe, )
+import Data.Bool (Bool, )
+import Data.Eq (Eq, )
 
 import System.Exit (ExitCode(ExitSuccess, ExitFailure), )
 
-import Prelude hiding (catch, )
+import Prelude (Show, Int, error, )
 
 
 -- * Plain monad
