@@ -17,6 +17,7 @@ import Control.Monad.Exception.Synchronous
    (Exceptional(Success, Exception), ExceptionalT(ExceptionalT), )
 import Control.Exception (IOException, try)
 import Control.Monad.IO.Class (MonadIO, liftIO, )
+import Control.Applicative (Applicative, )
 
 import System.IO.Unsafe (unsafeInterleaveIO, )
 
@@ -27,7 +28,7 @@ as a result of exceptional outcomes like \"File not found\".
 However an 'error' can well break the program.
 -}
 newtype SIO a = SIO (IO a) -- {sioToIO :: IO a}
-   deriving (Functor, Monad)
+   deriving (Functor, Applicative, Monad)
 
 
 sioToIO :: SIO a -> IO a
